#[non_exhaustive]
pub enum Event<'a> { LeaseFd { leased_fd: BorrowedFd<'a>, }, Finished, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


LeaseFd

shares the DRM file descriptor

This event returns a file descriptor suitable for use with DRM-related ioctls. The client should use drmModeGetLease to enumerate the DRM objects which have been leased to them. The compositor guarantees it will not use the leased DRM objects itself until it sends the finished event. If the compositor cannot or will not grant a lease for the requested connectors, it will not send this event, instead sending the finished event.

The compositor will send this event at most once during this objects lifetime.

Fields

leased_fd: BorrowedFd<'a>

leased DRM file descriptor



Finished

sent when the lease has been revoked

The compositor uses this event to either reject a lease request, or if it previously sent a lease_fd, to notify the client that the lease has been revoked. If the client requires a new lease, they should destroy this object and submit a new lease request. The compositor will send no further events for this object after sending the finish event. Compositors should revoke the lease when any of the leased resources become unavailable, namely when a hot-unplug occurs or when the compositor loses DRM master. Compositors may advertise the connector for leasing again, if the resource is available, by sending the connector event through the wp_drm_lease_device_v1 interface.

Implementations



impl<'a> Event<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message